changeset 56727:6b028bf60b4e

(Fsleep_for): Remove obsolete code. Rename wait_reading_process_input to wait_reading_process_output.
author Kim F. Storm <storm@cua.dk>
date Fri, 20 Aug 2004 10:33:05 +0000
parents 05cd07c4498a
children 1686b397ef16
files src/dispnew.c
diffstat 1 files changed, 4 insertions(+), 38 deletions(-) [+]
line wrap: on
line diff
--- a/src/dispnew.c	Fri Aug 20 10:22:39 2004 +0000
+++ b/src/dispnew.c	Fri Aug 20 10:33:05 2004 +0000
@@ -6331,47 +6331,13 @@
   if (sec < 0 || (sec == 0 && usec == 0))
     return Qnil;
 
-  wait_reading_process_input (sec, usec, 0, 0, Qnil, NULL, 0);
-
-  /* We should always have wait_reading_process_input; we have a dummy
-     implementation for systems which don't support subprocesses.  */
-#if 0
-  /* No wait_reading_process_input */
-  immediate_quit = 1;
-  QUIT;
-
-#ifdef VMS
-  sys_sleep (sec);
-#else /* not VMS */
-/* The reason this is done this way
-    (rather than defined (H_S) && defined (H_T))
-   is because the VMS preprocessor doesn't grok `defined'.  */
-#ifdef HAVE_SELECT
-  EMACS_GET_TIME (end_time);
-  EMACS_SET_SECS_USECS (timeout, sec, usec);
-  EMACS_ADD_TIME (end_time, end_time, timeout);
-
-  while (1)
-    {
-      EMACS_GET_TIME (timeout);
-      EMACS_SUB_TIME (timeout, end_time, timeout);
-      if (EMACS_TIME_NEG_P (timeout)
-	  || !select (1, 0, 0, 0, &timeout))
-	break;
-    }
-#else /* not HAVE_SELECT */
-  sleep (sec);
-#endif /* HAVE_SELECT */
-#endif /* not VMS */
-
-  immediate_quit = 0;
-#endif /* no subprocesses */
+  wait_reading_process_output (sec, usec, 0, 0, Qnil, NULL, 0);
 
   return Qnil;
 }
 
 
 /* This is just like wait_reading_process_input, except that
    it does the redisplay.
 
    It's also much like Fsit_for, except that it can be used for
@@ -6396,8 +6362,8 @@
   gobble_input (0);
 #endif
 
-  wait_reading_process_input (sec, usec, reading ? -1 : 1, display,
-			      Qnil, NULL, 0);
+  wait_reading_process_output (sec, usec, reading ? -1 : 1, display,
+			       Qnil, NULL, 0);
 
   return detect_input_pending () ? Qnil : Qt;
 }
@@ -6331,47 +6331,13 @@
 
 
-/* This is just like wait_reading_process_input, except that
+/* This is just like wait_reading_process_output, except that
    it does the redisplay.
 